<?php

namespace ADAToolbar;

use ADAToolbar\Traits\Singleton;
use ADAToolbar\Admin\Admin;
use ADAToolbar\Admin\Options;

class Plugin {

    use Singleton;
    
    public $version = ADATOOLBARVERSION;

    private $env = ADATOOLBARMODE;
    
    private $assets = [
        'dev' => [
            'public' => [
                'css' => 'public.css',
                'js'  => 'public.js',
            ],
            'admin' => [
                'css' => 'admin.css',
                'js'  => 'admin.js',
            ],

            'notices' => [
                'css' => 'notices.css',
                'js'  => 'notices.js',
            ],
        ],
        'prod' => [
            'public' => [
                'css' => 'public.min.css',
                'js'  => 'public.min.js',
            ],
            'admin' => [
                'css' => 'admin.min.css',
                'js'  => 'admin.min.js',
            ],
            'notices' => [
                'css' => 'notices.min.css',
                'js'  => 'notices.min.js',
            ],
        ],
    ];
    public $pluginPages = [
        'toplevel_page_accessibility-toolbar',
        'the-accessibility-toolbar_page_accessibility-toolbar-community',
        'the-accessibility-toolbar_page_accessibility-toolbar-pro',
        'the-accessibility-toolbar_page_accessibility-toolbar-element-controls',
    ];
    public function init(){
        Admin::getInstance();
        add_action( 'wp_enqueue_scripts', [$this, 'frontend_enqueue'] );
        add_action( 'admin_enqueue_scripts', [$this, 'admin_enqueue'] );
    }
    public function admin_enqueue($handle) {
        if(in_array($handle, $this->pluginPages)) {
            wp_enqueue_style( 'ada-tooolbar-admin-josefin-sans', 'https://fonts.googleapis.com/css?family=Josefin Sans' );
            wp_register_script( 'ada-toolbar-admin-js', plugins_url( 'accessibility-toolbar' ) . '/dist/'.$this->assets[$this->env]['admin']['js'],['jquery'], $this->version,true );
            wp_localize_script( 'ada-toolbar-admin-js', 'ATAdminData', [
                'nonce' => wp_create_nonce( 'wp_rest' ),
                'root' => esc_url_raw( rest_url() ),
                'assets'  => plugins_url( 'accessibility-toolbar' ).'/src/assets/',
            ] );
            wp_enqueue_script( 'ada-toolbar-admin-js' );
        }
        wp_register_script( 'ada-toolbar-admin-notices-js', plugins_url( 'accessibility-toolbar' ) . '/dist/'.$this->assets[$this->env]['notices']['js'],['jquery'], $this->version,true );
        wp_localize_script( 'ada-toolbar-admin-notices-js', 'ATAdminNoticesData', [
            'nonce' => wp_create_nonce( 'wp_rest' ),
            'root' => esc_url_raw( rest_url() ),
            'assets'  => plugins_url( 'accessibility-toolbar' ).'/src/assets/',
            'transient' => get_transient( '_transient_ll_at_upgrade_notice' ),
            'validLicense' =>  get_option('ll_at_license_status'),
        ] );
        wp_enqueue_script( 'ada-toolbar-admin-notices-js' );
    }
    public function frontend_enqueue() {
        wp_register_script( 'ada-toolbar-public-js', plugins_url( 'accessibility-toolbar' ) . '/dist/'.$this->assets[$this->env]['public']['js'],['jquery'], $this->version,true );
        $options = Options::getInstance()->getOptions([], true);
        if($options['options']['ll_at_enable']){
            wp_localize_script( 'ada-toolbar-public-js', 'ATPublicData', [
                'options'              =>   $options,
                'menu'                 =>   wp_get_nav_menu_items($options['options']['ll_at_accessibility_menu']),
                'assets'               =>   [
                    'logo' => plugins_url( 'accessibility-toolbar' ).'/src/assets/images/onlineadalogo.png',
                    'header_bg' => plugins_url( 'accessibility-toolbar' ).'/src/assets/images/headerbkgd.gif',
                ],
                'validLicense'         =>   get_option('ll_at_license_status'),
                'isEditor' => $this->is_elementor(),
            ] );
            wp_enqueue_script('ada-toolbar-public-font-awesome-js');
            wp_enqueue_script( 'ada-toolbar-public-js' );
        }

    }
    public function is_elementor(){
        if(class_exists('\Elementor\Plugin')){
            return \Elementor\Plugin::$instance->editor->is_edit_mode() || \Elementor\Plugin::$instance->preview->is_preview_mode();
        }
        return false;
    }

}